# ROOT_DIRECTORY = "/home/cloudam/workflow/"
ROOT_DIRECTORY = "D:/workdata/workflow/"
INPUT_FILE_DIRECTORY = ROOT_DIRECTORY+"cloudam_stream/manager/resources/"
CUSTOMIZE_ACTOR_PATH = 'customize_actor.'
INPUT_PORT_PATH = 'cloudam_stream.core.ports.inputports'
OUTPUT_PORT_PATH = 'cloudam_stream.core.ports.outputports'
PARAM_PATH = 'cloudam_stream.core.parameters'